@@ -146,30 +146,7 @@ public abstract class AbstractAdvertisementConfigService implements Advertisemen
         CacheService cacheService = Services.getService(CacheService.class);
         if (cacheService == null) {
             // get config without cache
-        	JSONValue result = getConfigByUserInternal(session);
-            if (result == null) {
-                String reseller = null;
-                String pack = null;
-                try {
-                    reseller = getReseller(session.getContextId());
-                } catch (OXException e) {
-                    LOG.debug("Error while retrieving the reseller for user {} in context {}.", session.getUserId(), session.getContextId(), e);
-                }
-                try {
-                    pack = getPackage(session);
-                } catch (OXException e) {
-                    LOG.debug("Error while retrieving the package for user {} in context {}.", session.getUserId(), session.getContextId(), e);
-                }
-                // fallback to defaults in case reseller or package is empty
-                if (Strings.isEmpty(reseller)) {
-                    reseller = RESELLER_ALL;
-                }
-                if (Strings.isEmpty(pack)) {
-                    pack = PACKAGE_ALL;
-                }
-                result = getConfigInternal(session, reseller, pack);
-            }
-            return result;
+            return loadInternalConfiguration(session);
         }
 
         //check user cache first
@@ -228,11 +205,38 @@ public abstract class AbstractAdvertisementConfigService implements Advertisemen
         return result;
     }
 
+    private JSONValue loadInternalConfiguration(Session session) throws OXException {
+        JSONValue result = getConfigByUserInternal(session);
+        if (result == null) {
+            String reseller = null;
+            String pack = null;
+            try {
+                reseller = getReseller(session.getContextId());
+            } catch (OXException e) {
+                LOG.debug("Error while retrieving the reseller for user {} in context {}.", session.getUserId(), session.getContextId(), e);
+            }
+            try {
+                pack = getPackage(session);
+            } catch (OXException e) {
+                LOG.debug("Error while retrieving the package for user {} in context {}.", session.getUserId(), session.getContextId(), e);
+            }
+            // fallback to defaults in case reseller or package is empty
+            if (Strings.isEmpty(reseller)) {
+                reseller = RESELLER_ALL;
+            }
+            if (Strings.isEmpty(pack)) {
+                pack = PACKAGE_ALL;
+            }
+            result = getConfigInternal(session, reseller, pack);
+        }
+        return result;
+    }
+
     private JSONValue getConfigByUserInternal(Session session) throws OXException {
         ConfigViewFactory factory = Services.getService(ConfigViewFactory.class);
         ConfigView view = factory.getView(session.getUserId(), session.getContextId());
         String id = view.get(PREVIEW_CONFIG, String.class);
-        if (!Strings.isEmpty(id)) {
+        if (Strings.isNotEmpty(id)) {
             int configId = Integer.parseInt(id);
 
             DatabaseService dbService = Services.getService(DatabaseService.class);
@@ -447,7 +451,7 @@ public abstract class AbstractAdvertisementConfigService implements Advertisemen
 
             if (result.next()) {
 
-                int configId = Integer.valueOf(result.getString(1));
+                int configId = Integer.parseInt(result.getString(1));
                 Databases.closeSQLStuff(result, stmt);
                 if (config == null) {
                     stmt = con.prepareStatement(SQL_DELETE_CONFIG);
@@ -531,7 +535,7 @@ public abstract class AbstractAdvertisementConfigService implements Advertisemen
     }
 
     @Override
-    public List<ConfigResult> setConfig(String reseller, Map<String, String> configs) throws OXException {
+    public List<ConfigResult> setConfig(String reseller, Map<String, String> configs) {
         List<ConfigResult> resultList = new ArrayList<>();
         for (Map.Entry<String, String> entry : configs.entrySet()) {
             try {
