@@ -103,10 +103,12 @@ public class AdvertisementPackageServiceImpl implements AdvertisementPackageServ
         int reslen = propNameBuilder.length();
         boolean containsDefault = false;
         for (ResellerAdmin res: resellerService.getAll()){
-            String packageScheme = configService.getProperty(AdvertisementConfigService.CONFIG_PREFIX + res.getName() + CONFIG_SUFFIX);
+            propNameBuilder.setLength(reslen);
+            String packageScheme = configService.getProperty(propNameBuilder.append(res.getName()).append(CONFIG_SUFFIX).toString());
             if (packageScheme == null) {
                 // Fall-back to reseller identifier
-                packageScheme = configService.getProperty(AdvertisementConfigService.CONFIG_PREFIX + res.getId() + CONFIG_SUFFIX);
+                propNameBuilder.setLength(reslen);
+                packageScheme = configService.getProperty(propNameBuilder.append(res.getId()).append(CONFIG_SUFFIX).toString());
 
                 if (packageScheme == null) {
                     // Fall-back to global as last resort
